@@ -1,10 +1,11 @@
+use std::convert::TryFrom;
 use std::path::PathBuf;
 
-use async_std::io::{Read, Write};
-use async_std::net::{TcpListener, TcpStream};
-use async_std::os::unix::net::{UnixListener, UnixStream};
-use async_tls::TlsAcceptor;
 use async_trait::async_trait;
+use rustls::ServerName;
+use tokio::io::{AsyncRead, AsyncWrite};
+use tokio::net::{TcpListener, TcpStream, UnixListener, UnixStream};
+use tokio_rustls::TlsAcceptor;
 
 use crate::error::Error;
 use crate::network::tls::{get_tls_connector, get_tls_listener};
@@ -55,10 +56,10 @@ impl Listener for UnixListener {
 
 /// A new trait, which can be used to represent Unix- and Tls encrypted TcpStreams. \
 /// This is necessary to write generic functions where both types can be used.
-pub trait Stream: Read + Write + Unpin + Send {}
+pub trait Stream: AsyncRead + AsyncWrite + Unpin + Send {}
 impl Stream for UnixStream {}
-impl Stream for async_tls::server::TlsStream<TcpStream> {}
-impl Stream for async_tls::client::TlsStream<TcpStream> {}
+impl Stream for tokio_rustls::server::TlsStream<TcpStream> {}
+impl Stream for tokio_rustls::client::TlsStream<TcpStream> {}
 
 /// Convenience type, so we don't have type write `Box<dyn Listener>` all the time.
 pub type GenericListener = Box<dyn Listener>;
@@ -71,13 +72,13 @@ pub type GenericStream = Box<dyn Stream>;
 pub async fn get_client_stream(settings: &Shared) -> Result<GenericStream, Error> {
     // Create a unix socket, if the config says so.
     if settings.use_unix_socket {
-        if !PathBuf::from(&settings.unix_socket_path()).exists() {
+        let unix_socket_path = settings.unix_socket_path();
+        if !PathBuf::from(&unix_socket_path).exists() {
             return Err(Error::FileNotFound(format!(
-                "Unix socket at path {:?}. Is the daemon started?",
-                &settings.unix_socket_path
+                "Unix socket at path {unix_socket_path:?}. Is the daemon started?",
             )));
         }
-        let stream = UnixStream::connect(&settings.unix_socket_path()).await?;
+        let stream = UnixStream::connect(&unix_socket_path).await?;
         return Ok(Box::new(stream));
     }
 
@@ -85,21 +86,20 @@ pub async fn get_client_stream(settings: &Shared) -> Result<GenericStream, Error
     let address = format!("{}:{}", &settings.host, &settings.port);
     let tcp_stream = TcpStream::connect(&address).await.map_err(|_| {
         Error::Connection(format!(
-            "Failed to connect to the daemon on {}. Did you start it?",
-            &address
+            "Failed to connect to the daemon on {address}. Did you start it?"
         ))
     })?;
 
     // Get the configured rustls TlsConnector
     let tls_connector = get_tls_connector(settings)
         .await
-        .map_err(|err| Error::Connection(format!("Failed to initialize tls connector {}.", err)))?;
+        .map_err(|err| Error::Connection(format!("Failed to initialize tls connector {err}.")))?;
 
     // Initialize the TLS layer
     let stream = tls_connector
-        .connect("pueue.local", tcp_stream)
+        .connect(ServerName::try_from("pueue.local").unwrap(), tcp_stream)
         .await
-        .map_err(|err| Error::Connection(format!("Failed to initialize tls {}.", err)))?;
+        .map_err(|err| Error::Connection(format!("Failed to initialize tls {err}.")))?;
 
     Ok(Box::new(stream))
 }
@@ -120,9 +120,7 @@ pub async fn get_listener(settings: &Shared) -> Result<GenericListener, Error> {
             std::fs::remove_file(&settings.unix_socket_path())?;
         }
 
-        return Ok(Box::new(
-            UnixListener::bind(&settings.unix_socket_path()).await?,
-        ));
+        return Ok(Box::new(UnixListener::bind(&settings.unix_socket_path())?));
     }
 
     // This is the listener, which accepts low-level TCP connections
