@@ -4,7 +4,7 @@ use chrono::prelude::*;
 use serde_derive::{Deserialize, Serialize};
 use strum_macros::Display;
 
-use crate::{aliasing::insert_alias, settings::PUEUE_DEFAULT_GROUP};
+use crate::{aliasing::insert_alias, state::PUEUE_DEFAULT_GROUP};
 
 /// This enum represents the status of the internal task handling of Pueue.
 /// They basically represent the internal task life-cycle.
